<?php

namespace Alive\Dm;

class Administration {

    public function __construct() {
        $this->init();
    }

    public function init() {
        add_action('admin_init', array($this, 'admin_init'));
        add_action('admin_menu', array($this, 'admin_menu'));
    }

    public function admin_menu() {
        add_options_page(
            'ALIVE Platform - Discount Manager',
            'ALIVE Platform - Discount Manager',
            'manage_options',
            'alive-dm-plugin-admin',
            array($this, 'options_page')
        );
    }

    public function options_page() {
        if (!current_user_can('manage_options')) {
            wp_die(__('You do not have sufficient permissions to access this page.'));
        }

        View_Engine::render('administration');
    }

    public function admin_init() {
        $this->add_general_section();
        $this->add_used_in_pages_setting();

        $this->add_local_section();
        $this->add_twitter_setting();
        $this->add_currency_setting();
        $this->add_currency_pos_setting();

        $this->add_map_section();
        $this->add_map_provider_setting();
        $this->add_google_api_key_setting();
        $this->add_initial_latitude_setting();
        $this->add_initial_longitude_setting();
        $this->add_initial_zoom_setting();

        $this->add_connection_section();
        $this->add_url_setting();
        $this->add_username_setting();
        $this->add_password_setting();
        $this->add_api_gateway_url_setting();
        $this->add_api_access_key_id_setting();
        $this->add_api_secret_access_key_setting();
        $this->add_ncdb_url_setting();
        $this->add_ncdb_username_setting();
        $this->add_ncdb_password_setting();

        $this->add_card_information_section();
        $this->add_isic_url();
        $this->add_isic_scholar_url();
        $this->add_itic_url();
        $this->add_iytc_url();
        $this->add_alive_url();
        $this->add_eyca_url();
    }

    private function add_general_section() {
        add_settings_section(
            'alive-dm-plugin-general',
            __DM('General settings'),
            function ($arg) { echo '<p>' . __dm('Here you should set up various settings regarding this plugin instance.') . '</p>'; },
            'alive-dm-plugin-admin'
        );
    }
    private function add_used_in_pages_setting() {
        $name = 'alive-dm-plugin-used-in-pages';
        add_settings_field(
            $name,
            __dm('Comma separated list of pages using discount search shortcode'),
            function () use ($name) {
                View_Engine::input_text($name, implode(', ', Config::used_in_pages()));
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-general'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }

    private function add_local_section() {
        add_settings_section(
            'alive-dm-plugin-local',
            __DM('Local settings'),
            function ($arg) { echo '<p>' . __dm('Here you should set up various settings regarding this plugin instance.') . '</p>'; },
            'alive-dm-plugin-admin'
        );
    }

    private function add_twitter_setting() {
        $name = 'alive-dm-plugin-twitter';
        add_settings_field(
            $name,
            __dm('Twitter account'),
            function () use ($name) {
                View_Engine::input_text($name, Config::twitter());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-local'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }

    private function add_currency_setting() {
        $name = 'alive-dm-plugin-currency';
        add_settings_field(
            $name,
            __dm('Currency'),
            function () use ($name) {
                View_Engine::input_text($name, Config::currency());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-local'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }

    private function add_currency_pos_setting() {
        $name = 'alive-dm-plugin-currency-pos';
        add_settings_field(
            $name,
            __dm('Currency position'),
            function () use ($name) {
                View_Engine::input_radio(
                    $name,
                    Config::currency_pos(),
                    array(
                        1 => __dm('currency_before'),
                        2 => __dm('currency_after'),
                    )
                );
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-local'
        );
        register_setting(
            'alive-dm-plugin-admin',
            $name,
            new Validator_Sanitizer(
                $name,
                'Alive\\Dm\\Config::currency_pos',
                array(
                    'is_currency_pos' => "don't hack",
                )
            )
        );
    }

    private function add_map_section() {
        add_settings_section(
            'alive-dm-plugin-gmap',
            __DM('Map settings'),
            function ($arg) { echo '<p>' . __dm('Here you should set up various settings for maps.') . '</p>'; },
            'alive-dm-plugin-admin'
        );
    }

    private function add_map_provider_setting() {
        $name = 'alive-dm-plugin-map-provider';
        add_settings_field(
            $name,
            __dm('Map provider'),
            function () use ($name) {
                View_Engine::input_radio(
                    $name,
                    Config::map_provider(),
                    array(
                        'google' => __dm('GoogleMap'),
                        'openStreet' => __dm('OpenStreetMap'),
                    )
                );
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-gmap'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }

    private function add_google_api_key_setting() {
        $name = 'alive-dm-plugin-google-api-key';
        add_settings_field(
            $name,
            __dm('Google API key'),
            function () use ($name) {
                View_Engine::input_text($name, Config::google_api_key());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-gmap'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }

    private function add_initial_latitude_setting() {
        $name = 'alive-dm-plugin-latitude';
        add_settings_field(
            $name,
            __dm('Latitude of initial map center'),
            function () use ($name) {
                View_Engine::input_text($name, Config::lat());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-gmap'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }

    private function add_initial_longitude_setting() {
        $name = 'alive-dm-plugin-longitude';
        add_settings_field(
            $name,
            __dm('Longitude of initial map center'),
            function () use ($name) {
                View_Engine::input_text($name, Config::lon());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-gmap'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }

    private function add_initial_zoom_setting() {
        $name = 'alive-dm-plugin-zoom';
        add_settings_field(
            $name,
            __dm('Zoom of initial map center'),
            function () use ($name) {
                View_Engine::input_text($name, Config::zoom());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-gmap'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }

    private function add_connection_section() {
        add_settings_section(
            'alive-dm-plugin-connection',
            __DM('Connection settings'),
            function ($arg) { echo '<p>' . __dm('Here you should set up connection to Discount Manager instance.') . '</p>'; },
            'alive-dm-plugin-admin'
        );
    }

    private function add_url_setting() {
        $name = 'alive-dm-plugin-dm-url';
        add_settings_field(
            $name,
            __dm('Url'),
            function () use ($name) {
                View_Engine::input_text($name, Config::url());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-connection'
        );
        register_setting(
            'alive-dm-plugin-admin',
            $name,
            new Validator_Sanitizer(
                $name,
                'Alive\\Dm\\Config::url',
                array(
                    'is_url' => __dm('Url is not in a valid format.'),
                )
            )
        );
    }

    private function add_username_setting() {
        $name = 'alive-dm-plugin-dm-username';
        add_settings_field(
            $name,
            __dm('Username'),
            function () use ($name) {
                View_Engine::input_text($name, Config::username());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-connection'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }

    private function add_password_setting() {
        $name = 'alive-dm-plugin-dm-password';
        add_settings_field(
            $name,
            __dm('Password'),
            function () use ($name) {
                View_Engine::input_text($name, Config::password());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-connection'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }


    private function add_api_gateway_url_setting() {
        $name = 'alive-dm-plugin-api-gateway-url';
        add_settings_field(
            $name,
            __dm('API gateway url'),
            function () use ($name) {
                View_Engine::input_text($name, Config::api_gateway_url());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-connection'
        );
        register_setting(
            'alive-dm-plugin-admin',
            $name,
            new Validator_Sanitizer(
                $name,
                'Alive\\Dm\\Config::url',
                array(
                    'is_url' => __dm('Url is not in a valid format.'),
                )
            )
        );
    }

    private function add_api_access_key_id_setting() {
        $name = 'alive-dm-plugin-api-access-key-id';
        add_settings_field(
            $name,
            __dm('API access key id'),
            function () use ($name) {
                View_Engine::input_text($name, Config::api_access_key_id());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-connection'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }

    private function add_api_secret_access_key_setting() {
        $name = 'alive-dm-plugin-api-secret-access-key';
        add_settings_field(
            $name,
            __dm('API secret access key'),
            function () use ($name) {
                View_Engine::input_text($name, Config::api_secret_access_key());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-connection'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }


    private function add_ncdb_url_setting() {
        $name = 'alive-dm-plugin-ncdb-url';
        add_settings_field(
            $name,
            __dm('NCDB Url'),
            function () use ($name) {
                View_Engine::input_text($name, Config::ncdb_url());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-connection'
        );
        register_setting(
            'alive-dm-plugin-admin',
            $name,
            new Validator_Sanitizer(
                $name,
                'Alive\\Dm\\Config::url',
                array(
                    'is_url' => __dm('Url is not in a valid format.'),
                )
            )
        );
    }

    private function add_ncdb_username_setting() {
        $name = 'alive-dm-plugin-ncdb-username';
        add_settings_field(
            $name,
            __dm('NCDB Username'),
            function () use ($name) {
                View_Engine::input_text($name, Config::ncdb_username());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-connection'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }

    private function add_ncdb_password_setting() {
        $name = 'alive-dm-plugin-ncdb-password';
        add_settings_field(
            $name,
            __dm('NCDB Password'),
            function () use ($name) {
                View_Engine::input_text($name, Config::ncdb_password());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-connection'
        );
        register_setting('alive-dm-plugin-admin', $name);
    }

    private function add_card_information_section() {
        add_settings_section(
            'alive-dm-plugin-card-information',
            __dm('Card information'),
            function ($arg) { echo '<p>' . __dm('Enter the URL names of pages where visitors will find information about their IDs. The icons of the card types in discount tiles link to the site. Leave the field blank to disable the feature.') . '</p>'; },
            'alive-dm-plugin-admin'
        );
    }

    private function add_isic_url() {
        $name = 'alive-dm-plugin-isic-url';
        add_settings_field(
            $name,
            __dm('ISIC'),
            function () use ($name) {
                View_Engine::input_text($name, Config::isic_url());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-card-information'
        );
        register_setting(
            'alive-dm-plugin-admin',
            $name
        );
    }

    private function add_isic_scholar_url() {
        $name = 'alive-dm-plugin-isic-scholar-url';
        add_settings_field(
            $name,
            __dm('ISIC SCHOLAR'),
            function () use ($name) {
                View_Engine::input_text($name, Config::isic_scholar_url());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-card-information'
        );
        register_setting(
            'alive-dm-plugin-admin',
            $name
        );
    }

    private function add_itic_url() {
        $name = 'alive-dm-plugin-itic-url';
        add_settings_field(
            $name,
            __dm('ITIC'),
            function () use ($name) {
                View_Engine::input_text($name, Config::itic_url());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-card-information'
        );
        register_setting(
            'alive-dm-plugin-admin',
            $name
        );
    }

    private function add_iytc_url() {
        $name = 'alive-dm-plugin-iytc-url';
        add_settings_field(
            $name,
            __dm('IYTC'),
            function () use ($name) {
                View_Engine::input_text($name, Config::iytc_url());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-card-information'
        );
        register_setting(
            'alive-dm-plugin-admin',
            $name
        );
    }

    private function add_alive_url() {
        $name = 'alive-dm-plugin-alive-url';
        add_settings_field(
            $name,
            __dm('ALIVE'),
            function () use ($name) {
                View_Engine::input_text($name, Config::alive_url());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-card-information'
        );
        register_setting(
            'alive-dm-plugin-admin',
            $name
        );
    }

    private function add_eyca_url() {
        $name = 'alive-dm-plugin-eyca-url';
        add_settings_field(
            $name,
            __dm('EYCA'),
            function () use ($name) {
                View_Engine::input_text($name, Config::eyca_url());
            },
            'alive-dm-plugin-admin',
            'alive-dm-plugin-card-information'
        );
        register_setting(
            'alive-dm-plugin-admin',
            $name
        );
    }
}
