<?php

namespace Alive\Dm;

class Newest_Discounts extends Short_Code {

    const DEFAULT_LIMIT = 10;

    public function load_scripts() {
        wp_enqueue_style("discount-search",
            plugins_url("resources/alive-dm/css/discount_search.css", dirname(__FILE__))
        );
        wp_enqueue_script('jquery');
    }

    protected function short_code() {
        return 'dm_newest_discounts';
    }

    public function handler($attributes) {
        $limit = empty($attributes['limit']) ? self::DEFAULT_LIMIT : $attributes['limit'];
        $discount_manager_client = new Discount_Manager_Client(Config::url(), Config::username(), Config::password(), Config::api_gateway_url(), Config::api_access_key_id(), Config::api_secret_access_key());
        $providers = $discount_manager_client->get_providers(array(
            'limit' => $limit,
            'sortKey' => 'modifiedOn',
            'sortOrder' => 'desc',
            'newest' => 'true'
        ));
        return $this->render($providers, (isset($attributes['search_page'])) ? $attributes['search_page'] : "");
    }

    private function render($providers, $search_page) {
        $html = "<div class='dm-newest-discounts'>";
        if (isset($providers)) {
            foreach ($providers->items as $provider) {
                $logoUrl = null;
                foreach ($provider->logo as $image) {
                    if ($image->type == "SMALL") {
                        $logoUrl = $image->url;
                        break;
                    }
                }
                if (!$logoUrl) {
                    $logoUrl = empty($provider->logoUrl) ?
                        plugins_url('alive-dm-plugin') . '/resources/alive-dm/img/isic-image.png' : $provider->logoUrl;
                }
                foreach ($provider->discounts as $discount) {
                    if (Dm_Utils::is_discount_active($discount)) {
                        $activeDiscount = $discount;
                        break;
                    }
                }
                if (isset($activeDiscount)) {
                    $html .= "<a href='/" . $search_page . "/" . $provider->slug . "/" . $provider->id . "'>" .
                        "<div class='dm-newest-discount clearfix' data-dm-provider-id='" . $provider->id . "'>" .
                        "<div class='dm-newest-discount-logo-wrapper'>" .
                        "<img src='$logoUrl' />" .
                        "</div>" .
                        "<div class='dm-newest-discount-info-wrapper'>" .
                        "<h3>" . Localizer::get_provider_value($provider, 'name') . "</h3>" .
                        "<p>" . Localizer::get_discount_type($activeDiscount) . "</p>" .
                        "<p>" . Localizer::get_category_name($activeDiscount->categories[0]) . "</p>" .
                        "</div>" .
                        "</div>" .
                        "</a>";
                }
            }
        } else {
            $html .= "<div class='dm-newest-discount-error'>" .
                "<img src=" .  plugins_url('alive-dm-plugin') . "/resources/alive-dm/img/alert.png'>" .
                "<p>" . __dm('Discount database is currently unavailable, try back later.') . "</p>" .
                "<p>" . __dm('We are sorry for complications.') . "</p> </div>" ;

        }

        $html .= "<div class='clearfix'></div>";
        $html .= "</div>";
        return $html;
    }
}
